"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TriggerMetricType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerMetricTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerMetricType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_METRIC_TYPE_NOT_VALID: _TriggerMetricType.ValueType  # 0
    TRIGGER_METRIC_TYPE_VALUE: _TriggerMetricType.ValueType  # 1
    TRIGGER_METRIC_TYPE_AVERAGE_VALUE: _TriggerMetricType.ValueType  # 2

class TriggerMetricType(_TriggerMetricType, metaclass=_TriggerMetricTypeEnumTypeWrapper): ...

TRIGGER_METRIC_TYPE_NOT_VALID: TriggerMetricType.ValueType  # 0
TRIGGER_METRIC_TYPE_VALUE: TriggerMetricType.ValueType  # 1
TRIGGER_METRIC_TYPE_AVERAGE_VALUE: TriggerMetricType.ValueType  # 2
global___TriggerMetricType = TriggerMetricType

class _KubeDeploymentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _KubeDeploymentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_KubeDeploymentType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _KubeDeploymentType.ValueType  # 0
    REALTIME: _KubeDeploymentType.ValueType  # 1
    STREAM: _KubeDeploymentType.ValueType  # 2

class KubeDeploymentType(_KubeDeploymentType, metaclass=_KubeDeploymentTypeEnumTypeWrapper): ...

UNKNOWN: KubeDeploymentType.ValueType  # 0
REALTIME: KubeDeploymentType.ValueType  # 1
STREAM: KubeDeploymentType.ValueType  # 2
global___KubeDeploymentType = KubeDeploymentType

class KubeAdvancedDeploymentOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NUMBER_OF_WORKERS_FIELD_NUMBER: builtins.int
    HTTP_REQUEST_TIMEOUT_MS_FIELD_NUMBER: builtins.int
    DAEMON_MODE_FIELD_NUMBER: builtins.int
    CUSTOM_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    MAX_BATCH_SIZE_FIELD_NUMBER: builtins.int
    DEPLOYMENT_PROCESS_TIMEOUT_LIMIT_FIELD_NUMBER: builtins.int
    PURCHASE_OPTION_FIELD_NUMBER: builtins.int
    number_of_workers: builtins.int
    """Number of workers http server"""
    http_request_timeout_ms: builtins.int
    """Timeout for request timeout"""
    @property
    def daemon_mode(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Serve model container in daemon mode"""
    custom_iam_role_arn: builtins.str
    """Custom IAM Role ARN"""
    max_batch_size: builtins.int
    """Max batch size of records"""
    deployment_process_timeout_limit: builtins.int
    """The timeout for the deployment (in seconds)"""
    purchase_option: builtins.str
    """Whether it is spot/ondemand (default - spot)"""
    def __init__(
        self,
        *,
        number_of_workers: builtins.int = ...,
        http_request_timeout_ms: builtins.int = ...,
        daemon_mode: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        custom_iam_role_arn: builtins.str = ...,
        max_batch_size: builtins.int = ...,
        deployment_process_timeout_limit: builtins.int = ...,
        purchase_option: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["daemon_mode", b"daemon_mode"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom_iam_role_arn", b"custom_iam_role_arn", "daemon_mode", b"daemon_mode", "deployment_process_timeout_limit", b"deployment_process_timeout_limit", "http_request_timeout_ms", b"http_request_timeout_ms", "max_batch_size", b"max_batch_size", "number_of_workers", b"number_of_workers", "purchase_option", b"purchase_option"]) -> None: ...

global___KubeAdvancedDeploymentOptions = KubeAdvancedDeploymentOptions

class KubeServingStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REALTIME_CONFIG_FIELD_NUMBER: builtins.int
    STREAM_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def realtime_config(self) -> global___RealTimeConfig:
        """RealTime will replace advanced - a placeholder for now"""
    @property
    def stream_config(self) -> global___StreamConfig:
        """Deploy using streaming solution (kafka)"""
    def __init__(
        self,
        *,
        realtime_config: global___RealTimeConfig | None = ...,
        stream_config: global___StreamConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["Strategy", b"Strategy", "realtime_config", b"realtime_config", "stream_config", b"stream_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["Strategy", b"Strategy", "realtime_config", b"realtime_config", "stream_config", b"stream_config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["Strategy", b"Strategy"]) -> typing_extensions.Literal["realtime_config", "stream_config"] | None: ...

global___KubeServingStrategy = KubeServingStrategy

class AutoScalingSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    MAX_REPLICA_COUNT_FIELD_NUMBER: builtins.int
    POLLING_INTERVAL_FIELD_NUMBER: builtins.int
    COOL_DOWN_PERIOD_FIELD_NUMBER: builtins.int
    TRIGGERS_FIELD_NUMBER: builtins.int
    min_replica_count: builtins.int
    """The minimum number of replicas will scale the resource down to"""
    max_replica_count: builtins.int
    """The maximum number of replicas of the target resource"""
    polling_interval: builtins.int
    """This is the interval to check each trigger on. By default it's every 30 seconds."""
    cool_down_period: builtins.int
    """The period to wait after the last trigger reported active before scaling the resource back to 0. By default it’s 5 minutes (300 seconds)."""
    @property
    def triggers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Triggers]:
        """List of triggers to activate scaling(up/down) of the target resource based on"""
    def __init__(
        self,
        *,
        min_replica_count: builtins.int = ...,
        max_replica_count: builtins.int = ...,
        polling_interval: builtins.int = ...,
        cool_down_period: builtins.int = ...,
        triggers: collections.abc.Iterable[global___Triggers] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cool_down_period", b"cool_down_period", "max_replica_count", b"max_replica_count", "min_replica_count", b"min_replica_count", "polling_interval", b"polling_interval", "triggers", b"triggers"]) -> None: ...

global___AutoScalingSpec = AutoScalingSpec

class Triggers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROMETHEUS_TRIGGER_FIELD_NUMBER: builtins.int
    @property
    def prometheus_trigger(self) -> global___PrometheusTrigger: ...
    def __init__(
        self,
        *,
        prometheus_trigger: global___PrometheusTrigger | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["prometheus_trigger", b"prometheus_trigger", "trigger_type", b"trigger_type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["prometheus_trigger", b"prometheus_trigger", "trigger_type", b"trigger_type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["trigger_type", b"trigger_type"]) -> typing_extensions.Literal["prometheus_trigger"] | None: ...

global___Triggers = Triggers

class PrometheusTrigger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METRIC_NAME_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    QUERY_FIELD_NUMBER: builtins.int
    METRIC_TYPE_FIELD_NUMBER: builtins.int
    metric_name: builtins.str
    """Name to identify the Metric in the external.metrics.k8s.io API"""
    threshold: builtins.int
    """Value to initiate scaling on"""
    query: builtins.str
    """Promql syntax query"""
    metric_type: global___TriggerMetricType.ValueType
    """Type of the metric"""
    def __init__(
        self,
        *,
        metric_name: builtins.str = ...,
        threshold: builtins.int = ...,
        query: builtins.str = ...,
        metric_type: global___TriggerMetricType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["metric_name", b"metric_name", "metric_type", b"metric_type", "query", b"query", "threshold", b"threshold"]) -> None: ...

global___PrometheusTrigger = PrometheusTrigger

class RealTimeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTED_VARIATION_MAPPING_NAME_FIELD_NUMBER: builtins.int
    ASSUMED_IAM_ROLE_ARN_FIELD_NUMBER: builtins.int
    selected_variation_mapping_name: builtins.str
    assumed_iam_role_arn: builtins.str
    def __init__(
        self,
        *,
        selected_variation_mapping_name: builtins.str = ...,
        assumed_iam_role_arn: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assumed_iam_role_arn", b"assumed_iam_role_arn", "selected_variation_mapping_name", b"selected_variation_mapping_name"]) -> None: ...

global___RealTimeConfig = RealTimeConfig

class StreamConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KAFKA_FIELD_NUMBER: builtins.int
    @property
    def kafka(self) -> global___KafkaConfig: ...
    def __init__(
        self,
        *,
        kafka: global___KafkaConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "kafka", b"kafka"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["configuration", b"configuration", "kafka", b"kafka"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["configuration", b"configuration"]) -> typing_extensions.Literal["kafka"] | None: ...

global___StreamConfig = StreamConfig

class KafkaConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Consumer(google.protobuf.message.Message):
        """The consumer config"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _AutoOffSetType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _AutoOffSetTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KafkaConfig.Consumer._AutoOffSetType.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: KafkaConfig.Consumer._AutoOffSetType.ValueType  # 0
            EARLIEST: KafkaConfig.Consumer._AutoOffSetType.ValueType  # 1
            LATEST: KafkaConfig.Consumer._AutoOffSetType.ValueType  # 2

        class AutoOffSetType(_AutoOffSetType, metaclass=_AutoOffSetTypeEnumTypeWrapper):
            """The offset types"""

        UNKNOWN: KafkaConfig.Consumer.AutoOffSetType.ValueType  # 0
        EARLIEST: KafkaConfig.Consumer.AutoOffSetType.ValueType  # 1
        LATEST: KafkaConfig.Consumer.AutoOffSetType.ValueType  # 2

        BOOTSTRAP_SERVER_FIELD_NUMBER: builtins.int
        TOPIC_FIELD_NUMBER: builtins.int
        GROUP_FIELD_NUMBER: builtins.int
        TIMEOUT_FIELD_NUMBER: builtins.int
        AUTO_OFFSET_TYPE_FIELD_NUMBER: builtins.int
        MAX_BATCH_SIZE_FIELD_NUMBER: builtins.int
        MAX_POLL_LATENCY_FIELD_NUMBER: builtins.int
        @property
        def bootstrap_server(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Bootstrap servers"""
        topic: builtins.str
        """Consumer Topic"""
        group: builtins.str
        """Consumer Group"""
        timeout: builtins.int
        """Consumer timeout"""
        auto_offset_type: global___KafkaConfig.Consumer.AutoOffSetType.ValueType
        """The offset for the consumer"""
        max_batch_size: builtins.int
        max_poll_latency: builtins.float
        def __init__(
            self,
            *,
            bootstrap_server: collections.abc.Iterable[builtins.str] | None = ...,
            topic: builtins.str = ...,
            group: builtins.str = ...,
            timeout: builtins.int = ...,
            auto_offset_type: global___KafkaConfig.Consumer.AutoOffSetType.ValueType = ...,
            max_batch_size: builtins.int = ...,
            max_poll_latency: builtins.float = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["auto_offset_type", b"auto_offset_type", "bootstrap_server", b"bootstrap_server", "group", b"group", "max_batch_size", b"max_batch_size", "max_poll_latency", b"max_poll_latency", "timeout", b"timeout", "topic", b"topic"]) -> None: ...

    class Producer(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _CompressionType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _CompressionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KafkaConfig.Producer._CompressionType.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            UNKNOWN: KafkaConfig.Producer._CompressionType.ValueType  # 0
            UNCOMPRESSED: KafkaConfig.Producer._CompressionType.ValueType  # 1
            GZIP: KafkaConfig.Producer._CompressionType.ValueType  # 2
            SNAPPY: KafkaConfig.Producer._CompressionType.ValueType  # 3
            LZ4: KafkaConfig.Producer._CompressionType.ValueType  # 4
            ZSTD: KafkaConfig.Producer._CompressionType.ValueType  # 5

        class CompressionType(_CompressionType, metaclass=_CompressionTypeEnumTypeWrapper):
            """The compression types"""

        UNKNOWN: KafkaConfig.Producer.CompressionType.ValueType  # 0
        UNCOMPRESSED: KafkaConfig.Producer.CompressionType.ValueType  # 1
        GZIP: KafkaConfig.Producer.CompressionType.ValueType  # 2
        SNAPPY: KafkaConfig.Producer.CompressionType.ValueType  # 3
        LZ4: KafkaConfig.Producer.CompressionType.ValueType  # 4
        ZSTD: KafkaConfig.Producer.CompressionType.ValueType  # 5

        BOOTSTRAP_SERVER_FIELD_NUMBER: builtins.int
        TOPIC_FIELD_NUMBER: builtins.int
        COMPRESSION_TYPE_FIELD_NUMBER: builtins.int
        @property
        def bootstrap_server(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """The producer bootstrap servers"""
        topic: builtins.str
        """The producer topic"""
        compression_type: global___KafkaConfig.Producer.CompressionType.ValueType
        """The producer compression type"""
        def __init__(
            self,
            *,
            bootstrap_server: collections.abc.Iterable[builtins.str] | None = ...,
            topic: builtins.str = ...,
            compression_type: global___KafkaConfig.Producer.CompressionType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["bootstrap_server", b"bootstrap_server", "compression_type", b"compression_type", "topic", b"topic"]) -> None: ...

    CONSUMER_FIELD_NUMBER: builtins.int
    PRODUCER_FIELD_NUMBER: builtins.int
    WORKERS_FIELD_NUMBER: builtins.int
    @property
    def consumer(self) -> global___KafkaConfig.Consumer:
        """Consumer config"""
    @property
    def producer(self) -> global___KafkaConfig.Producer:
        """Producer config"""
    workers: builtins.int
    """Number of prediction workers"""
    def __init__(
        self,
        *,
        consumer: global___KafkaConfig.Consumer | None = ...,
        producer: global___KafkaConfig.Producer | None = ...,
        workers: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["consumer", b"consumer", "producer", b"producer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["consumer", b"consumer", "producer", b"producer", "workers", b"workers"]) -> None: ...

global___KafkaConfig = KafkaConfig

class KubeDeploymentSize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _GpuType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _GpuTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KubeDeploymentSize._GpuType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INVALID_GPU: KubeDeploymentSize._GpuType.ValueType  # 0
        NVIDIA_K80: KubeDeploymentSize._GpuType.ValueType  # 1
        NVIDIA_V100: KubeDeploymentSize._GpuType.ValueType  # 2
        NVIDIA_A100: KubeDeploymentSize._GpuType.ValueType  # 3
        NVIDIA_T4: KubeDeploymentSize._GpuType.ValueType  # 4
        NVIDIA_A10G: KubeDeploymentSize._GpuType.ValueType  # 5
        NVIDIA_L4: KubeDeploymentSize._GpuType.ValueType  # 6
        NVIDIA_T4_1_4_15: KubeDeploymentSize._GpuType.ValueType  # 7
        """More specific node types
        t4.xl
        """
        NVIDIA_T4_1_8_30: KubeDeploymentSize._GpuType.ValueType  # 8
        """t4.2xl"""
        NVIDIA_T4_1_16_60: KubeDeploymentSize._GpuType.ValueType  # 9
        """t4.4xl"""
        NVIDIA_A100_80GB_8_96_1360: KubeDeploymentSize._GpuType.ValueType  # 10
        """a100.8xl"""
        NVIDIA_V100_1_8_52: KubeDeploymentSize._GpuType.ValueType  # 11
        """a100.xl"""
        NVIDIA_V100_4_32_208: KubeDeploymentSize._GpuType.ValueType  # 12
        """v100.4xl"""

    class GpuType(_GpuType, metaclass=_GpuTypeEnumTypeWrapper): ...
    INVALID_GPU: KubeDeploymentSize.GpuType.ValueType  # 0
    NVIDIA_K80: KubeDeploymentSize.GpuType.ValueType  # 1
    NVIDIA_V100: KubeDeploymentSize.GpuType.ValueType  # 2
    NVIDIA_A100: KubeDeploymentSize.GpuType.ValueType  # 3
    NVIDIA_T4: KubeDeploymentSize.GpuType.ValueType  # 4
    NVIDIA_A10G: KubeDeploymentSize.GpuType.ValueType  # 5
    NVIDIA_L4: KubeDeploymentSize.GpuType.ValueType  # 6
    NVIDIA_T4_1_4_15: KubeDeploymentSize.GpuType.ValueType  # 7
    """More specific node types
    t4.xl
    """
    NVIDIA_T4_1_8_30: KubeDeploymentSize.GpuType.ValueType  # 8
    """t4.2xl"""
    NVIDIA_T4_1_16_60: KubeDeploymentSize.GpuType.ValueType  # 9
    """t4.4xl"""
    NVIDIA_A100_80GB_8_96_1360: KubeDeploymentSize.GpuType.ValueType  # 10
    """a100.8xl"""
    NVIDIA_V100_1_8_52: KubeDeploymentSize.GpuType.ValueType  # 11
    """a100.xl"""
    NVIDIA_V100_4_32_208: KubeDeploymentSize.GpuType.ValueType  # 12
    """v100.4xl"""

    class _MemoryUnit:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MemoryUnitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KubeDeploymentSize._MemoryUnit.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: KubeDeploymentSize._MemoryUnit.ValueType  # 0
        MIB: KubeDeploymentSize._MemoryUnit.ValueType  # 1
        GIB: KubeDeploymentSize._MemoryUnit.ValueType  # 2

    class MemoryUnit(_MemoryUnit, metaclass=_MemoryUnitEnumTypeWrapper): ...
    UNKNOWN: KubeDeploymentSize.MemoryUnit.ValueType  # 0
    MIB: KubeDeploymentSize.MemoryUnit.ValueType  # 1
    GIB: KubeDeploymentSize.MemoryUnit.ValueType  # 2

    class GpuResources(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        GPU_TYPE_FIELD_NUMBER: builtins.int
        GPU_AMOUNT_FIELD_NUMBER: builtins.int
        gpu_type: global___KubeDeploymentSize.GpuType.ValueType
        """The type of the GPU"""
        gpu_amount: builtins.int
        """Amount of GPUs"""
        def __init__(
            self,
            *,
            gpu_type: global___KubeDeploymentSize.GpuType.ValueType = ...,
            gpu_amount: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["gpu_amount", b"gpu_amount", "gpu_type", b"gpu_type"]) -> None: ...

    NUMBER_OF_PODS_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_AMOUNT_FIELD_NUMBER: builtins.int
    MEMORY_UNITS_FIELD_NUMBER: builtins.int
    GPU_RESOURCES_FIELD_NUMBER: builtins.int
    number_of_pods: builtins.int
    """Number of pods to deploy"""
    cpu: builtins.float
    """Cpu"""
    memory_amount: builtins.int
    """Amount of memory"""
    memory_units: global___KubeDeploymentSize.MemoryUnit.ValueType
    """Units type of memory"""
    @property
    def gpu_resources(self) -> global___KubeDeploymentSize.GpuResources:
        """GPU Resource for deployed model"""
    def __init__(
        self,
        *,
        number_of_pods: builtins.int = ...,
        cpu: builtins.float = ...,
        memory_amount: builtins.int = ...,
        memory_units: global___KubeDeploymentSize.MemoryUnit.ValueType = ...,
        gpu_resources: global___KubeDeploymentSize.GpuResources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["gpu_resources", b"gpu_resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "gpu_resources", b"gpu_resources", "memory_amount", b"memory_amount", "memory_units", b"memory_units", "number_of_pods", b"number_of_pods"]) -> None: ...

global___KubeDeploymentSize = KubeDeploymentSize

class KubeRuntimeDeploymentSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _LogLevel:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KubeRuntimeDeploymentSettings._LogLevel.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NOT_SET: KubeRuntimeDeploymentSettings._LogLevel.ValueType  # 0
        ERROR: KubeRuntimeDeploymentSettings._LogLevel.ValueType  # 1
        WARN: KubeRuntimeDeploymentSettings._LogLevel.ValueType  # 2
        INFO: KubeRuntimeDeploymentSettings._LogLevel.ValueType  # 3
        DEBUG: KubeRuntimeDeploymentSettings._LogLevel.ValueType  # 4

    class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper): ...
    NOT_SET: KubeRuntimeDeploymentSettings.LogLevel.ValueType  # 0
    ERROR: KubeRuntimeDeploymentSettings.LogLevel.ValueType  # 1
    WARN: KubeRuntimeDeploymentSettings.LogLevel.ValueType  # 2
    INFO: KubeRuntimeDeploymentSettings.LogLevel.ValueType  # 3
    DEBUG: KubeRuntimeDeploymentSettings.LogLevel.ValueType  # 4

    ROOT_LOGGER_LEVEL_FIELD_NUMBER: builtins.int
    root_logger_level: global___KubeRuntimeDeploymentSettings.LogLevel.ValueType
    def __init__(
        self,
        *,
        root_logger_level: global___KubeRuntimeDeploymentSettings.LogLevel.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["root_logger_level", b"root_logger_level"]) -> None: ...

global___KubeRuntimeDeploymentSettings = KubeRuntimeDeploymentSettings



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class RequestedEntitiesMatrixRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITIES_TO_FEATURES_FIELD_NUMBER: builtins.int
    ENTITY_VALUES_MATRIX_FIELD_NUMBER: builtins.int
    REQUEST_META_DATA_FIELD_NUMBER: builtins.int
    @property
    def entities_to_features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntityToFeatures]: ...
    @property
    def entity_values_matrix(self) -> global___RequestedEntitiesMatrix: ...
    @property
    def request_meta_data(self) -> global___RequestMetaData: ...
    def __init__(
        self,
        *,
        entities_to_features: collections.abc.Iterable[global___EntityToFeatures] | None = ...,
        entity_values_matrix: global___RequestedEntitiesMatrix | None = ...,
        request_meta_data: global___RequestMetaData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity_values_matrix", b"entity_values_matrix", "request_meta_data", b"request_meta_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entities_to_features", b"entities_to_features", "entity_values_matrix", b"entity_values_matrix", "request_meta_data", b"request_meta_data"]) -> None: ...

global___RequestedEntitiesMatrixRequest = RequestedEntitiesMatrixRequest

class RequestMetaData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_NAME_FIELD_NUMBER: builtins.int
    NUM_KEYS_FIELD_NUMBER: builtins.int
    FEATURE_SET_NAMES_FIELD_NUMBER: builtins.int
    model_name: builtins.str
    num_keys: builtins.int
    @property
    def feature_set_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        model_name: builtins.str = ...,
        num_keys: builtins.int = ...,
        feature_set_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_set_names", b"feature_set_names", "model_name", b"model_name", "num_keys", b"num_keys"]) -> None: ...

global___RequestMetaData = RequestMetaData

class RequestedEntitiesMatrix(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEADER_FIELD_NUMBER: builtins.int
    ROWS_FIELD_NUMBER: builtins.int
    @property
    def header(self) -> global___EntitiesHeader:
        """e.g: this is a matrix
               user_id | post_id  -> this is a header
         0        107     10008     -> this is a row
         1        108     10087     -> this is a row
        """
    @property
    def rows(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EntityValueRow]: ...
    def __init__(
        self,
        *,
        header: global___EntitiesHeader | None = ...,
        rows: collections.abc.Iterable[global___EntityValueRow] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["header", b"header"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["header", b"header", "rows", b"rows"]) -> None: ...

global___RequestedEntitiesMatrix = RequestedEntitiesMatrix

class EntitiesHeader(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENTITY_NAMES_FIELD_NUMBER: builtins.int
    @property
    def entity_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """e.g:
         user_id | post_id -> this is a header
        """
    def __init__(
        self,
        *,
        entity_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_names", b"entity_names"]) -> None: ...

global___EntitiesHeader = EntitiesHeader

class EntityValueRow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    ENTITY_VALUES_FIELD_NUMBER: builtins.int
    index: builtins.int
    """e.g:
     index | user_id | post_id
     0        107     10008     -> this is a row
     1        108     10087     -> this is a row
    """
    @property
    def entity_values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        index: builtins.int = ...,
        entity_values: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_values", b"entity_values", "index", b"index"]) -> None: ...

global___EntityValueRow = EntityValueRow

class EntityToFeatures(google.protobuf.message.Message):
    """e.g:
    user_id -> ["name", "address", "last_login"]
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FEATURES_FIELD_NUMBER: builtins.int
    ENTITY_NAME_FIELD_NUMBER: builtins.int
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feature]:
        """Features to get from a key value"""
    entity_name: builtins.str
    """Entity name"""
    def __init__(
        self,
        *,
        features: collections.abc.Iterable[global___Feature] | None = ...,
        entity_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity_name", b"entity_name", "features", b"features"]) -> None: ...

global___EntityToFeatures = EntityToFeatures

class FeatureValuesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class Entity(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        NAME_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        name: builtins.str
        """Entity name - such as uuid, site id, etc."""
        value: builtins.str
        """Entity value to fetch"""
        def __init__(
            self,
            *,
            name: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "value", b"value"]) -> None: ...

    FEATURES_FIELD_NUMBER: builtins.int
    ENTITY_FIELD_NUMBER: builtins.int
    @property
    def features(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Feature]:
        """List of features to fetch."""
    @property
    def entity(self) -> global___FeatureValuesRequest.Entity:
        """Feature is requested for a single entity (user id for example)."""
    def __init__(
        self,
        *,
        features: collections.abc.Iterable[global___Feature] | None = ...,
        entity: global___FeatureValuesRequest.Entity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["entity", b"entity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["entity", b"entity", "features", b"features"]) -> None: ...

global___FeatureValuesRequest = FeatureValuesRequest

class Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BATCH_FEATURE_FIELD_NUMBER: builtins.int
    ON_THE_FLY_FEATURE_FIELD_NUMBER: builtins.int
    STREAMING_FEATURE_FIELD_NUMBER: builtins.int
    STREAMING_AGGREGATION_FIELD_NUMBER: builtins.int
    BATCH_V1_FEATURE_FIELD_NUMBER: builtins.int
    STREAMING_V1_FEATURE_FIELD_NUMBER: builtins.int
    @property
    def batch_feature(self) -> global___BatchFeature: ...
    @property
    def on_the_fly_feature(self) -> global___OnTheFlyFeature: ...
    @property
    def streaming_feature(self) -> global___StreamingFeature: ...
    @property
    def streaming_aggregation(self) -> global___StreamingAggregationFeature: ...
    @property
    def batch_v1_feature(self) -> global___BatchV1Feature: ...
    @property
    def streaming_v1_feature(self) -> global___StreamingV1Feature: ...
    def __init__(
        self,
        *,
        batch_feature: global___BatchFeature | None = ...,
        on_the_fly_feature: global___OnTheFlyFeature | None = ...,
        streaming_feature: global___StreamingFeature | None = ...,
        streaming_aggregation: global___StreamingAggregationFeature | None = ...,
        batch_v1_feature: global___BatchV1Feature | None = ...,
        streaming_v1_feature: global___StreamingV1Feature | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["batch_feature", b"batch_feature", "batch_v1_feature", b"batch_v1_feature", "on_the_fly_feature", b"on_the_fly_feature", "streaming_aggregation", b"streaming_aggregation", "streaming_feature", b"streaming_feature", "streaming_v1_feature", b"streaming_v1_feature", "type", b"type"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["batch_feature", b"batch_feature", "batch_v1_feature", b"batch_v1_feature", "on_the_fly_feature", b"on_the_fly_feature", "streaming_aggregation", b"streaming_aggregation", "streaming_feature", b"streaming_feature", "streaming_v1_feature", b"streaming_v1_feature", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["type", b"type"]) -> typing_extensions.Literal["batch_feature", "on_the_fly_feature", "streaming_feature", "streaming_aggregation", "batch_v1_feature", "streaming_v1_feature"] | None: ...

global___Feature = Feature

class BatchFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___BatchFeature = BatchFeature

class BatchV1Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___BatchV1Feature = BatchV1Feature

class StreamingFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___StreamingFeature = StreamingFeature

class StreamingV1Feature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___StreamingV1Feature = StreamingV1Feature

class StreamingAggregationFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___StreamingAggregationFeature = StreamingAggregationFeature

class OnTheFlyFeature(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ON_THE_FLY_DATA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The feature name"""
    @property
    def on_the_fly_data(self) -> global___OnTheFlyData:
        """The data to transform"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        on_the_fly_data: global___OnTheFlyData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["on_the_fly_data", b"on_the_fly_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "on_the_fly_data", b"on_the_fly_data"]) -> None: ...

global___OnTheFlyFeature = OnTheFlyFeature

class MultiFeatureValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PANDAS_DF_AS_JSON_FIELD_NUMBER: builtins.int
    FEATURE_VALUES_FIELD_NUMBER: builtins.int
    pandas_df_as_json: builtins.str
    feature_values: builtins.str
    def __init__(
        self,
        *,
        pandas_df_as_json: builtins.str = ...,
        feature_values: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_values", b"feature_values", "pandas_df_as_json", b"pandas_df_as_json"]) -> None: ...

global___MultiFeatureValuesResponse = MultiFeatureValuesResponse

class FeatureValuesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class FeatureValue(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _ValueStatus:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ValueStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeatureValuesResponse.FeatureValue._ValueStatus.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            INVALID: FeatureValuesResponse.FeatureValue._ValueStatus.ValueType  # 0
            """Feature value could not be obtained"""
            VALID: FeatureValuesResponse.FeatureValue._ValueStatus.ValueType  # 1
            """Feature value is set"""

        class ValueStatus(_ValueStatus, metaclass=_ValueStatusEnumTypeWrapper): ...
        INVALID: FeatureValuesResponse.FeatureValue.ValueStatus.ValueType  # 0
        """Feature value could not be obtained"""
        VALID: FeatureValuesResponse.FeatureValue.ValueStatus.ValueType  # 1
        """Feature value is set"""

        FEATURE_NAME_FIELD_NUMBER: builtins.int
        FEATURE_VALUE_FIELD_NUMBER: builtins.int
        STATUS_FIELD_NUMBER: builtins.int
        feature_name: builtins.str
        """Name of requested feature"""
        @property
        def feature_value(self) -> global___Value:
            """Feature value as fetched from the service"""
        status: global___FeatureValuesResponse.FeatureValue.ValueStatus.ValueType
        """Feature value status"""
        def __init__(
            self,
            *,
            feature_name: builtins.str = ...,
            feature_value: global___Value | None = ...,
            status: global___FeatureValuesResponse.FeatureValue.ValueStatus.ValueType = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["feature_value", b"feature_value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["feature_name", b"feature_name", "feature_value", b"feature_value", "status", b"status"]) -> None: ...

    FEATURE_VALUES_FIELD_NUMBER: builtins.int
    @property
    def feature_values(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FeatureValuesResponse.FeatureValue]:
        """List of of features values, containing name and value data."""
    def __init__(
        self,
        *,
        feature_values: collections.abc.Iterable[global___FeatureValuesResponse.FeatureValue] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feature_values", b"feature_values"]) -> None: ...

global___FeatureValuesResponse = FeatureValuesResponse

class OnTheFlyData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_DATA_FIELD_NUMBER: builtins.int
    SCHEMA_DATA_FIELD_NUMBER: builtins.int
    user_data: builtins.str
    schema_data: builtins.str
    def __init__(
        self,
        *,
        user_data: builtins.str = ...,
        schema_data: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "schema_data", b"schema_data", "user_data", b"user_data"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "schema_data", b"schema_data", "user_data", b"user_data"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data", b"data"]) -> typing_extensions.Literal["user_data", "schema_data"] | None: ...

global___OnTheFlyData = OnTheFlyData

class Value(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BYTES_VAL_FIELD_NUMBER: builtins.int
    STRING_VAL_FIELD_NUMBER: builtins.int
    INT32_VAL_FIELD_NUMBER: builtins.int
    INT64_VAL_FIELD_NUMBER: builtins.int
    DOUBLE_VAL_FIELD_NUMBER: builtins.int
    FLOAT_VAL_FIELD_NUMBER: builtins.int
    BOOL_VAL_FIELD_NUMBER: builtins.int
    TIMESTAMP_VAL_FIELD_NUMBER: builtins.int
    ARRAY_VAL_FIELD_NUMBER: builtins.int
    bytes_val: builtins.bytes
    string_val: builtins.str
    int32_val: builtins.int
    int64_val: builtins.int
    double_val: builtins.float
    float_val: builtins.float
    bool_val: builtins.bool
    @property
    def timestamp_val(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def array_val(self) -> global___Array: ...
    def __init__(
        self,
        *,
        bytes_val: builtins.bytes = ...,
        string_val: builtins.str = ...,
        int32_val: builtins.int = ...,
        int64_val: builtins.int = ...,
        double_val: builtins.float = ...,
        float_val: builtins.float = ...,
        bool_val: builtins.bool = ...,
        timestamp_val: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        array_val: global___Array | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["array_val", b"array_val", "bool_val", b"bool_val", "bytes_val", b"bytes_val", "double_val", b"double_val", "float_val", b"float_val", "int32_val", b"int32_val", "int64_val", b"int64_val", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "val", b"val"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_val", b"array_val", "bool_val", b"bool_val", "bytes_val", b"bytes_val", "double_val", b"double_val", "float_val", b"float_val", "int32_val", b"int32_val", "int64_val", b"int64_val", "string_val", b"string_val", "timestamp_val", b"timestamp_val", "val", b"val"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["val", b"val"]) -> typing_extensions.Literal["bytes_val", "string_val", "int32_val", "int64_val", "double_val", "float_val", "bool_val", "timestamp_val", "array_val"] | None: ...

global___Value = Value

class Array(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ARRAY_VAL_FIELD_NUMBER: builtins.int
    @property
    def array_val(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Value]: ...
    def __init__(
        self,
        *,
        array_val: collections.abc.Iterable[global___Value] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["array_val", b"array_val"]) -> None: ...

global___Array = Array



"""Cluster V2 API client.

Provides wrapper methods for the Cluster V2 gRPC service with proper error handling.
"""

from _qwak_proto.qwak.administration.cluster.v2.cluster_pb2 import (
    ClusterSpec,
)
from _qwak_proto.qwak.administration.cluster.v2.cluster_service_pb2 import (
    CreateClusterCreationRequestRequest,
    CreateClusterCreationRequestResponse,
    DeleteClusterRequest,
    DeleteClusterResponse,
    GetClusterRequest,
    GetClusterResponse,
    GetClusterStateRequest,
    GetClusterStateResponse,
    ListClustersRequest,
    ListClustersResponse,
    UpdateClusterConfigurationRequest,
    UpdateClusterConfigurationResponse,
)
from _qwak_proto.qwak.administration.cluster.v2.cluster_service_pb2_grpc import (
    ClusterServiceStub,
)
from dependency_injector.wiring import Provide
from qwak.inner.di_configuration import QwakContainer
from qwak.inner.tool.grpc.grpc_try_wrapping import grpc_try_catch_wrapper


class ClusterV2Client:
    """Client for interacting with the Cluster V2 API.

    This client wraps the gRPC stub and provides methods with proper error handling
    using the grpc_try_catch_wrapper decorator.
    """

    def __init__(self, grpc_channel=Provide[QwakContainer.core_grpc_channel]):
        self.__cluster_service = ClusterServiceStub(grpc_channel)

    @grpc_try_catch_wrapper("Failed to create cluster")
    def create_cluster(
        self, cluster_spec: ClusterSpec
    ) -> CreateClusterCreationRequestResponse:
        """Create a new cluster.

        Args:
            cluster_spec: The cluster specification.

        Returns:
            CreateClusterCreationRequestResponse with the request_id.
        """
        request = CreateClusterCreationRequestRequest(cluster_spec=cluster_spec)
        return self.__cluster_service.CreateClusterCreationRequest(request)

    @grpc_try_catch_wrapper("Failed to get cluster state for request {request_id}")
    def get_cluster_state(self, request_id: str) -> GetClusterStateResponse:
        """Get cluster state by request ID.

        Args:
            request_id: The request ID from create_cluster.

        Returns:
            GetClusterStateResponse with the cluster state.
        """
        request = GetClusterStateRequest(request_id=request_id)
        return self.__cluster_service.GetClusterState(request)

    @grpc_try_catch_wrapper("Failed to get cluster {cluster_id}")
    def get_cluster(self, cluster_id: str) -> GetClusterResponse:
        """Get cluster by ID.

        Args:
            cluster_id: The cluster ID.

        Returns:
            GetClusterResponse with the cluster state.
        """
        request = GetClusterRequest(cluster_id=cluster_id)
        return self.__cluster_service.GetCluster(request)

    @grpc_try_catch_wrapper("Failed to list clusters")
    def list_clusters(self) -> ListClustersResponse:
        """List all clusters.

        Returns:
            ListClustersResponse with list of clusters.
        """
        request = ListClustersRequest()
        return self.__cluster_service.ListClusters(request)

    @grpc_try_catch_wrapper("Failed to update cluster {cluster_id}")
    def update_cluster(
        self, cluster_id: str, cluster_spec: ClusterSpec
    ) -> UpdateClusterConfigurationResponse:
        """Update cluster configuration.

        Args:
            cluster_id: The cluster ID to update.
            cluster_spec: The updated cluster specification.

        Returns:
            UpdateClusterConfigurationResponse with the request_id.
        """
        request = UpdateClusterConfigurationRequest(
            cluster_id=cluster_id,
            cluster_spec=cluster_spec,
        )
        return self.__cluster_service.UpdateClusterConfiguration(request)

    @grpc_try_catch_wrapper("Failed to delete cluster {cluster_id}")
    def delete_cluster(self, cluster_id: str) -> DeleteClusterResponse:
        """Delete cluster by ID.

        Args:
            cluster_id: The cluster ID to delete.

        Returns:
            DeleteClusterResponse with the request_id.
        """
        request = DeleteClusterRequest(cluster_id=cluster_id)
        return self.__cluster_service.DeleteCluster(request)



from dataclasses import dataclass
from typing import List

from _qwak_proto.qwak.build.v1.build_pb2 import ModelSchema as ProtoModelSchema
from qwak.model._entity_extraction import enrich_schema
from qwak.model.schema_entities import (
    BaseFeature,
    Entity,
    ExplicitFeature,
    FeatureStoreInput,
    InferenceOutput,
)

__all__ = ["ModelSchema", "ExplicitFeature", "InferenceOutput", "FeatureStoreInput"]


@dataclass
class ModelSchema:
    """
    The ModelSchema class provides a structured representation of a Machine Learning (ML) model's schema.
     It captures the details such as input features, output predictions, and entities, providing a standard way to
    communicate these details between different components of an ML system.
    """

    def __init__(
        self,
        entities: List[Entity] = None,
        inputs: List[BaseFeature] = None,
        outputs: List[InferenceOutput] = None,
    ):
        """
        Initializes the ModelSchema object with entities, inputs, and outputs.

        Args:
            entities (List[Entity], optional): A list of Entity objects. Defaults to None.
            inputs (List[BaseFeature], optional): A list of BaseFeature objects. Defaults to None.
            outputs (List[InferenceOutput], optional): A list of InferenceOutput objects. Defaults to None.

        Raises:
            TypeError: If entities, inputs, or outputs are not provided in the correct format.
        """
        raw_entities = entities if entities else []
        raw_inputs = inputs if inputs else []
        self._inputs, self._entities = enrich_schema(raw_inputs, raw_entities)
        self._outputs = outputs if outputs else []

    def to_proto(self):
        return ProtoModelSchema(
            entities=[entity.to_proto() for entity in self._entities],
            features=[feature.to_proto() for feature in self._inputs],
            inference_output=[inference.to_proto() for inference in self._outputs],
        )



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import qwak.administration.runtime_configuration.v0.creds.secret_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class ContainerRegistryConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUTH_FIELD_NUMBER: builtins.int
    @property
    def auth(self) -> global___ContainerRegistryAuthentication: ...
    def __init__(
        self,
        *,
        auth: global___ContainerRegistryAuthentication | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth", b"auth"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth", b"auth"]) -> None: ...

global___ContainerRegistryConfiguration = ContainerRegistryConfiguration

class ContainerRegistryAuthentication(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_PULL_SECRET_FIELD_NUMBER: builtins.int
    @property
    def image_pull_secret(self) -> global___ImagePullSecret: ...
    def __init__(
        self,
        *,
        image_pull_secret: global___ImagePullSecret | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "image_pull_secret", b"image_pull_secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "image_pull_secret", b"image_pull_secret"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["auth_type", b"auth_type"]) -> typing_extensions.Literal["image_pull_secret"] | None: ...

global___ContainerRegistryAuthentication = ContainerRegistryAuthentication

class ImagePullSecret(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SECRET_FIELD_NUMBER: builtins.int
    @property
    def secret(self) -> qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef: ...
    def __init__(
        self,
        *,
        secret: qwak.administration.runtime_configuration.v0.creds.secret_pb2.SecretKeyRef | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["secret", b"secret"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["secret", b"secret"]) -> None: ...

global___ImagePullSecret = ImagePullSecret



from typing import Optional

from frogml_storage.models.entity_manifest import Checksums


class DownloadContext(object):
    """
    A class to represent the arguments for a download operation.

    Attributes
    ----------
    repo_key : str
        The key of the repository where the artifact is located.
    source_url : str
        The source relative URL of the artifact, relative to artifactory url and the repo key.
    target_path : str
        The target path where the artifact will be downloaded to.
    exists_locally : bool
        A flag indicating whether the artifact already exists locally in the target path.
    artifact_checksum: Checksums
        The checksum of the artifact.
    """

    repo_key: str
    source_url: str
    target_path: str
    exists_locally: bool = False
    artifact_checksum: Optional[Checksums]

    def __init__(
        self,
        repo_key: str,
        source_url: str,
        target_path: str,
        exists_locally: bool = False,
        artifact_checksum: Optional[Checksums] = None,
    ):
        self.repo_key = repo_key
        self.source_url = source_url
        self.target_path = target_path
        self.exists_locally = exists_locally
        self.artifact_checksum = artifact_checksum

    def __eq__(self, other):
        if not isinstance(other, DownloadContext):
            return False

        return (
            self.repo_key == other.repo_key
            and self.source_url == other.source_url
            and self.target_path == other.target_path
            and self.exists_locally == other.exists_locally
            and self.artifact_checksum == other.artifact_checksum
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/ecosystem/v0/ecosystem_runtime_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from _qwak_proto.qwak.ecosystem.v0 import ecosystem_pb2 as qwak_dot_ecosystem_dot_v0_dot_ecosystem__pb2
from _qwak_proto.qwak.ecosystem.v0 import credentials_pb2 as qwak_dot_ecosystem_dot_v0_dot_credentials__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1qwak/ecosystem/v0/ecosystem_runtime_service.proto\x12\x11qwak.ecosystem.v0\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!qwak/ecosystem/v0/ecosystem.proto\x1a#qwak/ecosystem/v0/credentials.proto\x1a\x1egoogle/protobuf/duration.proto\"\xc1\x01\n\x13\x41uthenticateRequest\x12M\n\x18username_password_method\x18\x01 \x01(\x0b\x32).qwak.ecosystem.v0.UsernamePasswordMethodH\x00\x12\x42\n\x13qwak_api_key_method\x18\x02 \x01(\x0b\x32#.qwak.ecosystem.v0.QwakApiKeyMethodH\x00\x42\x17\n\x15\x61uthentication_method\"\\\n\x14\x41uthenticateResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12.\n\nexpired_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"$\n\"GetAuthenticatedUserContextRequest\"v\n#GetAuthenticatedUserContextResponse\x12O\n\x1a\x61uthenticated_user_context\x18\x01 \x01(\x0b\x32+.qwak.ecosystem.v0.AuthenticatedUserContext\"C\n\x1cGetUnifiedUserContextRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x12\n\naccount_id\x18\x02 \x01(\t\"b\n\x1dGetUnifiedUserContextResponse\x12\x41\n\x0cuser_context\x18\x01 \x01(\x0b\x32+.qwak.ecosystem.v0.AuthenticatedUserContext\"M\n\x11GetAccountRequest\x12\x14\n\naccount_id\x18\x01 \x01(\tH\x00\x12\x18\n\x0e\x65nvironment_id\x18\x02 \x01(\tH\x00\x42\x08\n\x06get_by\"P\n\x12GetAccountResponse\x12:\n\x0f\x61\x63\x63ount_details\x18\x01 \x01(\x0b\x32!.qwak.ecosystem.v0.AccountDetails\"\x19\n\x17ListUserAccountsRequest\"Y\n\x18ListUserAccountsResponse\x12=\n\x11user_account_list\x18\x01 \x01(\x0b\x32\".qwak.ecosystem.v0.UserAccountList\"b\n\x1aGetCloudCredentialsRequest\x12\x44\n\nparameters\x18\x01 \x01(\x0b\x32\x30.qwak.ecosystem.v0.GetCloudCredentialsParameters\"\x86\x01\n\x1dGetCloudCredentialsParameters\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x38\n\x0epermission_set\x18\x02 \x01(\x0b\x32 .qwak.ecosystem.v0.PermissionSet\"\xb0\x05\n\rPermissionSet\x12S\n\x19\x65\x64ge_environment_workload\x18\x01 \x01(\x0b\x32*.qwak.ecosystem.v0.EdgeEnvironmentWorkloadB\x02\x18\x01H\x00\x12\x38\n\rcore_services\x18\x02 \x01(\x0b\x32\x1f.qwak.ecosystem.v0.CoreServicesH\x00\x12T\n\x1coffline_feature_store_client\x18\x03 \x01(\x0b\x32,.qwak.ecosystem.v0.OfflineFeatureStoreClientH\x00\x12G\n\x15remote_build_executor\x18\x04 \x01(\x0b\x32&.qwak.ecosystem.v0.RemoteBuildExecutorH\x00\x12X\n\x1epull_models_container_registry\x18\x05 \x01(\x0b\x32..qwak.ecosystem.v0.PullModelsContainerRegistryH\x00\x12\x41\n\x12\x62\x61tch_job_executor\x18\x06 \x01(\x0b\x32#.qwak.ecosystem.v0.BatchJobExecutorH\x00\x12G\n\x15\x66\x65\x61ture_set_processor\x18\x07 \x01(\x0b\x32&.qwak.ecosystem.v0.FeatureSetProcessorH\x00\x12@\n\x11\x61nalytics_service\x18\x08 \x01(\x0b\x32#.qwak.ecosystem.v0.AnalyticsServiceH\x00\x12>\n\x10\x61nalytics_client\x18\t \x01(\x0b\x32\".qwak.ecosystem.v0.AnalyticsClientH\x00\x42\t\n\x07subject\"1\n\x17\x45\x64geEnvironmentWorkload\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"&\n\x0c\x43oreServices\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"3\n\x19OfflineFeatureStoreClient\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"-\n\x13RemoteBuildExecutor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"5\n\x1bPullModelsContainerRegistry\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"*\n\x10\x42\x61tchJobExecutor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"-\n\x13\x46\x65\x61tureSetProcessor\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"*\n\x10\x41nalyticsService\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\")\n\x0f\x41nalyticsClient\x12\x16\n\x0e\x65nvironment_id\x18\x01 \x01(\t\"]\n\x1bGetCloudCredentialsResponse\x12>\n\x11\x63loud_credentials\x18\x01 \x01(\x0b\x32#.qwak.ecosystem.v0.CloudCredentials2\xc0\x05\n\x14QwakEcosystemRuntime\x12_\n\x0c\x41uthenticate\x12&.qwak.ecosystem.v0.AuthenticateRequest\x1a\'.qwak.ecosystem.v0.AuthenticateResponse\x12\x8c\x01\n\x1bGetAuthenticatedUserContext\x12\x35.qwak.ecosystem.v0.GetAuthenticatedUserContextRequest\x1a\x36.qwak.ecosystem.v0.GetAuthenticatedUserContextResponse\x12k\n\x10ListUserAccounts\x12*.qwak.ecosystem.v0.ListUserAccountsRequest\x1a+.qwak.ecosystem.v0.ListUserAccountsResponse\x12Y\n\nGetAccount\x12$.qwak.ecosystem.v0.GetAccountRequest\x1a%.qwak.ecosystem.v0.GetAccountResponse\x12t\n\x13GetCloudCredentials\x12-.qwak.ecosystem.v0.GetCloudCredentialsRequest\x1a..qwak.ecosystem.v0.GetCloudCredentialsResponse\x12z\n\x15GetUnifiedUserContext\x12/.qwak.ecosystem.v0.GetUnifiedUserContextRequest\x1a\x30.qwak.ecosystem.v0.GetUnifiedUserContextResponseB\xb7\x01\n\x1c\x63om.qwak.ai.common.ecosystemP\x01Z\x94\x01github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.ecosystem.v0.ecosystem_runtime_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.qwak.ai.common.ecosystemP\001Z\224\001github.com/qwak-ai/qwak-platform/services/shared/java/libs/qwak-common/qwak-common-api/qwak-platform-ecosystem-api/pb/qwak/ecosystem/v0;ecosystem_v0'
  _PERMISSIONSET.fields_by_name['edge_environment_workload']._options = None
  _PERMISSIONSET.fields_by_name['edge_environment_workload']._serialized_options = b'\030\001'
  _globals['_AUTHENTICATEREQUEST']._serialized_start=210
  _globals['_AUTHENTICATEREQUEST']._serialized_end=403
  _globals['_AUTHENTICATERESPONSE']._serialized_start=405
  _globals['_AUTHENTICATERESPONSE']._serialized_end=497
  _globals['_GETAUTHENTICATEDUSERCONTEXTREQUEST']._serialized_start=499
  _globals['_GETAUTHENTICATEDUSERCONTEXTREQUEST']._serialized_end=535
  _globals['_GETAUTHENTICATEDUSERCONTEXTRESPONSE']._serialized_start=537
  _globals['_GETAUTHENTICATEDUSERCONTEXTRESPONSE']._serialized_end=655
  _globals['_GETUNIFIEDUSERCONTEXTREQUEST']._serialized_start=657
  _globals['_GETUNIFIEDUSERCONTEXTREQUEST']._serialized_end=724
  _globals['_GETUNIFIEDUSERCONTEXTRESPONSE']._serialized_start=726
  _globals['_GETUNIFIEDUSERCONTEXTRESPONSE']._serialized_end=824
  _globals['_GETACCOUNTREQUEST']._serialized_start=826
  _globals['_GETACCOUNTREQUEST']._serialized_end=903
  _globals['_GETACCOUNTRESPONSE']._serialized_start=905
  _globals['_GETACCOUNTRESPONSE']._serialized_end=985
  _globals['_LISTUSERACCOUNTSREQUEST']._serialized_start=987
  _globals['_LISTUSERACCOUNTSREQUEST']._serialized_end=1012
  _globals['_LISTUSERACCOUNTSRESPONSE']._serialized_start=1014
  _globals['_LISTUSERACCOUNTSRESPONSE']._serialized_end=1103
  _globals['_GETCLOUDCREDENTIALSREQUEST']._serialized_start=1105
  _globals['_GETCLOUDCREDENTIALSREQUEST']._serialized_end=1203
  _globals['_GETCLOUDCREDENTIALSPARAMETERS']._serialized_start=1206
  _globals['_GETCLOUDCREDENTIALSPARAMETERS']._serialized_end=1340
  _globals['_PERMISSIONSET']._serialized_start=1343
  _globals['_PERMISSIONSET']._serialized_end=2031
  _globals['_EDGEENVIRONMENTWORKLOAD']._serialized_start=2033
  _globals['_EDGEENVIRONMENTWORKLOAD']._serialized_end=2082
  _globals['_CORESERVICES']._serialized_start=2084
  _globals['_CORESERVICES']._serialized_end=2122
  _globals['_OFFLINEFEATURESTORECLIENT']._serialized_start=2124
  _globals['_OFFLINEFEATURESTORECLIENT']._serialized_end=2175
  _globals['_REMOTEBUILDEXECUTOR']._serialized_start=2177
  _globals['_REMOTEBUILDEXECUTOR']._serialized_end=2222
  _globals['_PULLMODELSCONTAINERREGISTRY']._serialized_start=2224
  _globals['_PULLMODELSCONTAINERREGISTRY']._serialized_end=2277
  _globals['_BATCHJOBEXECUTOR']._serialized_start=2279
  _globals['_BATCHJOBEXECUTOR']._serialized_end=2321
  _globals['_FEATURESETPROCESSOR']._serialized_start=2323
  _globals['_FEATURESETPROCESSOR']._serialized_end=2368
  _globals['_ANALYTICSSERVICE']._serialized_start=2370
  _globals['_ANALYTICSSERVICE']._serialized_end=2412
  _globals['_ANALYTICSCLIENT']._serialized_start=2414
  _globals['_ANALYTICSCLIENT']._serialized_end=2455
  _globals['_GETCLOUDCREDENTIALSRESPONSE']._serialized_start=2457
  _globals['_GETCLOUDCREDENTIALSRESPONSE']._serialized_end=2550
  _globals['_QWAKECOSYSTEMRUNTIME']._serialized_start=2553
  _globals['_QWAKECOSYSTEMRUNTIME']._serialized_end=3257
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from _qwak_proto.qwak.administration.cluster.v2 import cluster_service_pb2 as qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2


class ClusterServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateClusterCreationRequest = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/CreateClusterCreationRequest',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.FromString,
                )
        self.GetClusterState = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/GetClusterState',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.FromString,
                )
        self.UpdateClusterConfiguration = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/UpdateClusterConfiguration',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.FromString,
                )
        self.DeleteCluster = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/DeleteCluster',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
                )
        self.GetCluster = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/GetCluster',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.FromString,
                )
        self.ListClusters = channel.unary_unary(
                '/qwak.administration.cluster.v2.ClusterService/ListClusters',
                request_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.FromString,
                )


class ClusterServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateClusterCreationRequest(self, request, context):
        """Create a Cluster
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetClusterState(self, request, context):
        """Get Cluster state by request id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClusterConfiguration(self, request, context):
        """Update a Cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCluster(self, request, context):
        """Delete Cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCluster(self, request, context):
        """Get cluster by id
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListClusters(self, request, context):
        """List all clusters by filter
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateClusterCreationRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClusterCreationRequest,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.SerializeToString,
            ),
            'GetClusterState': grpc.unary_unary_rpc_method_handler(
                    servicer.GetClusterState,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.SerializeToString,
            ),
            'UpdateClusterConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClusterConfiguration,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.SerializeToString,
            ),
            'DeleteCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCluster,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.SerializeToString,
            ),
            'GetCluster': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCluster,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.SerializeToString,
            ),
            'ListClusters': grpc.unary_unary_rpc_method_handler(
                    servicer.ListClusters,
                    request_deserializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.FromString,
                    response_serializer=qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'qwak.administration.cluster.v2.ClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ClusterService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateClusterCreationRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/CreateClusterCreationRequest',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.CreateClusterCreationRequestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetClusterState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/GetClusterState',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterStateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateClusterConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/UpdateClusterConfiguration',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.UpdateClusterConfigurationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/DeleteCluster',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.DeleteClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCluster(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/GetCluster',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.GetClusterResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListClusters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/qwak.administration.cluster.v2.ClusterService/ListClusters',
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
            qwak_dot_administration_dot_cluster_dot_v2_dot_cluster__service__pb2.ListClustersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.cluster.v2.cluster_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class CreateClusterCreationRequestRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_SPEC_FIELD_NUMBER: builtins.int
    @property
    def cluster_spec(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterSpec:
        """The cluster to create"""
    def __init__(
        self,
        *,
        cluster_spec: qwak.administration.cluster.v2.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> None: ...

global___CreateClusterCreationRequestRequest = CreateClusterCreationRequestRequest

class CreateClusterCreationRequestResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___CreateClusterCreationRequestResponse = CreateClusterCreationRequestResponse

class GetClusterStateRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___GetClusterStateRequest = GetClusterStateRequest

class GetClusterStateResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_STATE_FIELD_NUMBER: builtins.int
    @property
    def cluster_state(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterState: ...
    def __init__(
        self,
        *,
        cluster_state: qwak.administration.cluster.v2.cluster_pb2.ClusterState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> None: ...

global___GetClusterStateResponse = GetClusterStateResponse

class GetClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to get"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___GetClusterRequest = GetClusterRequest

class GetClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_STATE_FIELD_NUMBER: builtins.int
    @property
    def cluster_state(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterState: ...
    def __init__(
        self,
        *,
        cluster_state: qwak.administration.cluster.v2.cluster_pb2.ClusterState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_state", b"cluster_state"]) -> None: ...

global___GetClusterResponse = GetClusterResponse

class UpdateClusterConfigurationRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    CLUSTER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to update"""
    @property
    def cluster_spec(self) -> qwak.administration.cluster.v2.cluster_pb2.ClusterSpec:
        """The updated spec of the cluster"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        cluster_spec: qwak.administration.cluster.v2.cluster_pb2.ClusterSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster_spec", b"cluster_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "cluster_spec", b"cluster_spec"]) -> None: ...

global___UpdateClusterConfigurationRequest = UpdateClusterConfigurationRequest

class UpdateClusterConfigurationResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___UpdateClusterConfigurationResponse = UpdateClusterConfigurationResponse

class DeleteClusterRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """The cluster id to delete"""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id"]) -> None: ...

global___DeleteClusterRequest = DeleteClusterRequest

class DeleteClusterResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["request_id", b"request_id"]) -> None: ...

global___DeleteClusterResponse = DeleteClusterResponse

class ListClustersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListClustersRequest = ListClustersRequest

class ListClustersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[qwak.administration.cluster.v2.cluster_pb2.Cluster]: ...
    def __init__(
        self,
        *,
        cluster: collections.abc.Iterable[qwak.administration.cluster.v2.cluster_pb2.Cluster] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> None: ...

global___ListClustersResponse = ListClustersResponse



#
#    Copyright 2024 OpenAI
#
#    Licensed under the Apache License, Version 2.0 (the "License");
#    you may not use this file except in compliance with the License.
#    You may obtain a copy of the License at
#
#        http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS,
#    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#    See the License for the specific language governing permissions and
#    limitations under the License.

from dataclasses import dataclass
from typing import List, Optional

from .chat_completion_message_tool_call import ChatCompletionMessageToolCall

__all__ = ["ChatCompletionMessage", "FunctionCall"]


@dataclass
class FunctionCall:
    arguments: str
    """
    The arguments to call the function with, as generated by the model in JSON
    format. Note that the model does not always generate valid JSON, and may
    hallucinate parameters not defined by your function schema. Validate the
    arguments in your code before calling your function.
    """

    name: str
    """The name of the function to call."""


@dataclass
class ChatCompletionMessage:
    role: str
    """The role of the author of this message."""

    content: Optional[str] = None
    """The contents of the message."""

    function_call: Optional[FunctionCall] = None
    """Deprecated and replaced by `tool_calls`.

    The name and arguments of a function that should be called, as generated by the
    model.
    """

    tool_calls: Optional[List[ChatCompletionMessageToolCall]] = None
    """The tool calls generated by the model, such as function calls."""

    def __post_init__(self):
        """Validates that the role type is correct."""
        if self.role != "assistant":
            raise ValueError(f"Invalid object type: '{self.role}'. Must be 'assistant'")



from typing import Optional


class QwakSuggestionException(Exception):
    def __init__(
        self,
        message: str,
        src_exception: Optional[Exception] = None,
        suggestion: Optional[str] = "",
    ):
        self._message = message
        self._src_exception = str(src_exception) if src_exception else ""
        self._suggestion = suggestion

    @property
    def message(self) -> str:
        if self._src_exception:
            msg = f"""Message: {self._message}.
Exception message: {self._src_exception}.
Recommendation: {self._suggestion}."""
        else:
            msg = f"""Message: {self._message}.
Recommendation: {self._suggestion}."""
        return msg

    def __str__(self):
        return self.message



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/execution/v1/execution_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.execution.v1 import backfill_pb2 as qwak_dot_execution_dot_v1_dot_backfill__pb2
from _qwak_proto.qwak.execution.v1 import batch_pb2 as qwak_dot_execution_dot_v1_dot_batch__pb2
from _qwak_proto.qwak.execution.v1 import deletion_pb2 as qwak_dot_execution_dot_v1_dot_deletion__pb2
from _qwak_proto.qwak.execution.v1 import streaming_pb2 as qwak_dot_execution_dot_v1_dot_streaming__pb2
from _qwak_proto.qwak.execution.v1 import streaming_aggregation_pb2 as qwak_dot_execution_dot_v1_dot_streaming__aggregation__pb2
from _qwak_proto.qwak.execution.v1 import execution_pb2 as qwak_dot_execution_dot_v1_dot_execution__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)qwak/execution/v1/execution_service.proto\x12\x1fqwak.feature.store.execution.v1\x1a qwak/execution/v1/backfill.proto\x1a\x1dqwak/execution/v1/batch.proto\x1a qwak/execution/v1/deletion.proto\x1a!qwak/execution/v1/streaming.proto\x1a-qwak/execution/v1/streaming_aggregation.proto\x1a!qwak/execution/v1/execution.proto\")\n\'ListLastExecutionsForEnvironmentRequest\"\xb5\x02\n(ListLastExecutionsForEnvironmentResponse\x12\x93\x01\n\x1f\x66\x65\x61tureset_id_to_last_execution\x18\x01 \x03(\x0b\x32j.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentResponse.FeaturesetIdToLastExecutionEntry\x1as\n FeaturesetIdToLastExecutionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry:\x02\x38\x01\"^\n\x16TriggerBackfillRequest\x12\x44\n\rbackfill_spec\x18\x01 \x01(\x0b\x32-.qwak.feature.store.execution.v1.BackfillSpec\"/\n\x17TriggerBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"1\n\x19GetExecutionStatusRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"h\n\x1aGetExecutionStatusResponse\x12J\n\x10\x65xecution_status\x18\x01 \x01(\x0e\x32\x30.qwak.feature.store.execution.v1.ExecutionStatus\"0\n\x18GetExecutionEntryRequest\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"e\n\x19GetExecutionEntryResponse\x12H\n\x0f\x65xecution_entry\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"i\n\x1dTriggerBatchFeaturesetRequest\x12H\n\x0f\x62\x61tch_ingestion\x18\x01 \x01(\x0b\x32/.qwak.feature.store.execution.v1.BatchIngestion\"6\n\x1eTriggerBatchFeaturesetResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\":\n!GetRunningExecutionEntriesRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"p\n\"GetRunningExecutionEntriesResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"9\n TriggerFeaturesetDeletionRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"9\n!TriggerFeaturesetDeletionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"<\n#InitPaginationByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\"Y\n$InitPaginationByFeaturesetIdResponse\x12\x14\n\x0crecord_count\x18\x01 \x01(\x03\x12\x1b\n\x13max_execution_index\x18\x02 \x01(\x03\"\x81\x01\n#ListExecutionsByFeaturesetIdRequest\x12\x15\n\rfeatureset_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x13\n\x0bpage_number\x18\x03 \x01(\x05\x12\x1b\n\x13max_execution_index\x18\x04 \x01(\x03\"r\n$ListExecutionsByFeaturesetIdResponse\x12J\n\x11\x65xecution_entries\x18\x01 \x03(\x0b\x32/.qwak.feature.store.execution.v1.ExecutionEntry\"\x87\x01\n&TriggerOnlineStreamingIngestionRequest\x12]\n\x1aonline_streaming_ingestion\x18\x01 \x01(\x0b\x32\x39.qwak.feature.store.execution.v1.OnlineStreamingIngestion\"?\n\'TriggerOnlineStreamingIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x8a\x01\n\'TriggerOfflineStreamingIngestionRequest\x12_\n\x1boffline_streaming_ingestion\x18\x01 \x01(\x0b\x32:.qwak.feature.store.execution.v1.OfflineStreamingIngestion\"@\n(TriggerOfflineStreamingIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x9a\x01\n3TriggerRowLevelStreamingAggregationIngestionRequest\x12\x63\n\x13row_level_ingestion\x18\x01 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.RowLevelStreamingAggregationIngestion\"L\n4TriggerRowLevelStreamingAggregationIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x9f\x01\n5TriggerCompactionStreamingAggregationIngestionRequest\x12\x66\n\x14\x63ompaction_ingestion\x18\x01 \x01(\x0b\x32H.qwak.feature.store.execution.v1.CompactionStreamingAggregationIngestion\"N\n6TriggerCompactionStreamingAggregationIngestionResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t\"\x86\x01\n*TriggerStreamingAggregationBackfillRequest\x12X\n\x08\x62\x61\x63kfill\x18\x01 \x01(\x0b\x32\x46.qwak.feature.store.execution.v1.StreamingAggregationBackfillIngestion\"C\n+TriggerStreamingAggregationBackfillResponse\x12\x14\n\x0c\x65xecution_id\x18\x01 \x01(\t2\xbc\x13\n\x1c\x46\x65\x61tureStoreExecutionService\x12\x89\x01\n\x14TriggerBatchBackfill\x12\x37.qwak.feature.store.execution.v1.TriggerBackfillRequest\x1a\x38.qwak.feature.store.execution.v1.TriggerBackfillResponse\x12\x99\x01\n\x16TriggerBatchFeatureset\x12>.qwak.feature.store.execution.v1.TriggerBatchFeaturesetRequest\x1a?.qwak.feature.store.execution.v1.TriggerBatchFeaturesetResponse\x12\xb4\x01\n\x1fTriggerOnlineStreamingIngestion\x12G.qwak.feature.store.execution.v1.TriggerOnlineStreamingIngestionRequest\x1aH.qwak.feature.store.execution.v1.TriggerOnlineStreamingIngestionResponse\x12\xb7\x01\n TriggerOfflineStreamingIngestion\x12H.qwak.feature.store.execution.v1.TriggerOfflineStreamingIngestionRequest\x1aI.qwak.feature.store.execution.v1.TriggerOfflineStreamingIngestionResponse\x12\xdb\x01\n,TriggerRowLevelStreamingAggregationIngestion\x12T.qwak.feature.store.execution.v1.TriggerRowLevelStreamingAggregationIngestionRequest\x1aU.qwak.feature.store.execution.v1.TriggerRowLevelStreamingAggregationIngestionResponse\x12\xe1\x01\n.TriggerCompactionStreamingAggregationIngestion\x12V.qwak.feature.store.execution.v1.TriggerCompactionStreamingAggregationIngestionRequest\x1aW.qwak.feature.store.execution.v1.TriggerCompactionStreamingAggregationIngestionResponse\x12\xc0\x01\n#TriggerStreamingAggregationBackfill\x12K.qwak.feature.store.execution.v1.TriggerStreamingAggregationBackfillRequest\x1aL.qwak.feature.store.execution.v1.TriggerStreamingAggregationBackfillResponse\x12\xa2\x01\n\x19TriggerFeaturesetDeletion\x12\x41.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionRequest\x1a\x42.qwak.feature.store.execution.v1.TriggerFeaturesetDeletionResponse\x12\x8d\x01\n\x12GetExecutionStatus\x12:.qwak.feature.store.execution.v1.GetExecutionStatusRequest\x1a;.qwak.feature.store.execution.v1.GetExecutionStatusResponse\x12\x8a\x01\n\x11GetExecutionEntry\x12\x39.qwak.feature.store.execution.v1.GetExecutionEntryRequest\x1a:.qwak.feature.store.execution.v1.GetExecutionEntryResponse\x12\xa5\x01\n\x1aGetRunningExecutionEntries\x12\x42.qwak.feature.store.execution.v1.GetRunningExecutionEntriesRequest\x1a\x43.qwak.feature.store.execution.v1.GetRunningExecutionEntriesResponse\x12\xab\x01\n\x1cInitPaginationByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.InitPaginationByFeaturesetIdResponse\x12\xab\x01\n\x1cListExecutionsByFeaturesetId\x12\x44.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdRequest\x1a\x45.qwak.feature.store.execution.v1.ListExecutionsByFeaturesetIdResponse\x12\xb7\x01\n ListLastExecutionsForEnvironment\x12H.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentRequest\x1aI.qwak.feature.store.execution.v1.ListLastExecutionsForEnvironmentResponseB)\n%com.qwak.ai.features.execution.api.v1P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.execution.v1.execution_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%com.qwak.ai.features.execution.api.v1P\001'
  _LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY._options = None
  _LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY._serialized_options = b'8\001'
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTREQUEST']._serialized_start=294
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTREQUEST']._serialized_end=335
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE']._serialized_start=338
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE']._serialized_end=647
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY']._serialized_start=532
  _globals['_LISTLASTEXECUTIONSFORENVIRONMENTRESPONSE_FEATURESETIDTOLASTEXECUTIONENTRY']._serialized_end=647
  _globals['_TRIGGERBACKFILLREQUEST']._serialized_start=649
  _globals['_TRIGGERBACKFILLREQUEST']._serialized_end=743
  _globals['_TRIGGERBACKFILLRESPONSE']._serialized_start=745
  _globals['_TRIGGERBACKFILLRESPONSE']._serialized_end=792
  _globals['_GETEXECUTIONSTATUSREQUEST']._serialized_start=794
  _globals['_GETEXECUTIONSTATUSREQUEST']._serialized_end=843
  _globals['_GETEXECUTIONSTATUSRESPONSE']._serialized_start=845
  _globals['_GETEXECUTIONSTATUSRESPONSE']._serialized_end=949
  _globals['_GETEXECUTIONENTRYREQUEST']._serialized_start=951
  _globals['_GETEXECUTIONENTRYREQUEST']._serialized_end=999
  _globals['_GETEXECUTIONENTRYRESPONSE']._serialized_start=1001
  _globals['_GETEXECUTIONENTRYRESPONSE']._serialized_end=1102
  _globals['_TRIGGERBATCHFEATURESETREQUEST']._serialized_start=1104
  _globals['_TRIGGERBATCHFEATURESETREQUEST']._serialized_end=1209
  _globals['_TRIGGERBATCHFEATURESETRESPONSE']._serialized_start=1211
  _globals['_TRIGGERBATCHFEATURESETRESPONSE']._serialized_end=1265
  _globals['_GETRUNNINGEXECUTIONENTRIESREQUEST']._serialized_start=1267
  _globals['_GETRUNNINGEXECUTIONENTRIESREQUEST']._serialized_end=1325
  _globals['_GETRUNNINGEXECUTIONENTRIESRESPONSE']._serialized_start=1327
  _globals['_GETRUNNINGEXECUTIONENTRIESRESPONSE']._serialized_end=1439
  _globals['_TRIGGERFEATURESETDELETIONREQUEST']._serialized_start=1441
  _globals['_TRIGGERFEATURESETDELETIONREQUEST']._serialized_end=1498
  _globals['_TRIGGERFEATURESETDELETIONRESPONSE']._serialized_start=1500
  _globals['_TRIGGERFEATURESETDELETIONRESPONSE']._serialized_end=1557
  _globals['_INITPAGINATIONBYFEATURESETIDREQUEST']._serialized_start=1559
  _globals['_INITPAGINATIONBYFEATURESETIDREQUEST']._serialized_end=1619
  _globals['_INITPAGINATIONBYFEATURESETIDRESPONSE']._serialized_start=1621
  _globals['_INITPAGINATIONBYFEATURESETIDRESPONSE']._serialized_end=1710
  _globals['_LISTEXECUTIONSBYFEATURESETIDREQUEST']._serialized_start=1713
  _globals['_LISTEXECUTIONSBYFEATURESETIDREQUEST']._serialized_end=1842
  _globals['_LISTEXECUTIONSBYFEATURESETIDRESPONSE']._serialized_start=1844
  _globals['_LISTEXECUTIONSBYFEATURESETIDRESPONSE']._serialized_end=1958
  _globals['_TRIGGERONLINESTREAMINGINGESTIONREQUEST']._serialized_start=1961
  _globals['_TRIGGERONLINESTREAMINGINGESTIONREQUEST']._serialized_end=2096
  _globals['_TRIGGERONLINESTREAMINGINGESTIONRESPONSE']._serialized_start=2098
  _globals['_TRIGGERONLINESTREAMINGINGESTIONRESPONSE']._serialized_end=2161
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONREQUEST']._serialized_start=2164
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONREQUEST']._serialized_end=2302
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONRESPONSE']._serialized_start=2304
  _globals['_TRIGGEROFFLINESTREAMINGINGESTIONRESPONSE']._serialized_end=2368
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_start=2371
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_end=2525
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_start=2527
  _globals['_TRIGGERROWLEVELSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_end=2603
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_start=2606
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONREQUEST']._serialized_end=2765
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_start=2767
  _globals['_TRIGGERCOMPACTIONSTREAMINGAGGREGATIONINGESTIONRESPONSE']._serialized_end=2845
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_start=2848
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLREQUEST']._serialized_end=2982
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_start=2984
  _globals['_TRIGGERSTREAMINGAGGREGATIONBACKFILLRESPONSE']._serialized_end=3051
  _globals['_FEATURESTOREEXECUTIONSERVICE']._serialized_start=3054
  _globals['_FEATURESTOREEXECUTIONSERVICE']._serialized_end=5546
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import qwak.administration.account.v1.account_pb2
import qwak.administration.account.v1.jfrog_tenant_details_pb2
import qwak.administration.account.v1.preferences_pb2
import qwak.administration.account.v1.terms_pb2
import qwak.administration.v0.environments.configuration_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class AccountStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCOUNT_CREATION_IN_PROGRESS_FIELD_NUMBER: builtins.int
    ACCOUNT_READY_FIELD_NUMBER: builtins.int
    ACCOUNT_DOESNT_EXIST_FIELD_NUMBER: builtins.int
    @property
    def account_creation_in_progress(self) -> global___AccountCreationInProgress: ...
    @property
    def account_ready(self) -> global___AccountReady: ...
    @property
    def account_doesnt_exist(self) -> global___AccountDoesntExist: ...
    def __init__(
        self,
        *,
        account_creation_in_progress: global___AccountCreationInProgress | None = ...,
        account_ready: global___AccountReady | None = ...,
        account_doesnt_exist: global___AccountDoesntExist | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_doesnt_exist", b"account_doesnt_exist", "account_ready", b"account_ready", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_creation_in_progress", b"account_creation_in_progress", "account_doesnt_exist", b"account_doesnt_exist", "account_ready", b"account_ready", "status", b"status"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["status", b"status"]) -> typing_extensions.Literal["account_creation_in_progress", "account_ready", "account_doesnt_exist"] | None: ...

global___AccountStatus = AccountStatus

class AccountCreationInProgress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___AccountCreationInProgress = AccountCreationInProgress

class AccountReady(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class EnvironmentsByIdEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___EnvironmentDetails: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___EnvironmentDetails | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    PREFERENCES_FIELD_NUMBER: builtins.int
    DEFAULT_ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENTS_BY_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    JFROG_TENANT_DETAILS_FIELD_NUMBER: builtins.int
    ACCEPTED_TERMS_FIELD_NUMBER: builtins.int
    account_id: builtins.str
    """The account id"""
    account_name: builtins.str
    """Account name"""
    @property
    def preferences(self) -> qwak.administration.account.v1.preferences_pb2.AccountPreferences:
        """Account preferences"""
    default_environment_id: builtins.str
    """default environment id"""
    @property
    def environments_by_id(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___EnvironmentDetails]:
        """Map of environments by the id"""
    type: qwak.administration.account.v1.account_pb2.AccountType.ValueType
    """The type of the account"""
    tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType
    """The tier of the account"""
    @property
    def jfrog_tenant_details(self) -> qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantDetails:
        """The JFrog tenant details"""
    @property
    def accepted_terms(self) -> qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms:
        """The accepted terms of the account"""
    def __init__(
        self,
        *,
        account_id: builtins.str = ...,
        account_name: builtins.str = ...,
        preferences: qwak.administration.account.v1.preferences_pb2.AccountPreferences | None = ...,
        default_environment_id: builtins.str = ...,
        environments_by_id: collections.abc.Mapping[builtins.str, global___EnvironmentDetails] | None = ...,
        type: qwak.administration.account.v1.account_pb2.AccountType.ValueType = ...,
        tier: qwak.administration.account.v1.account_pb2.AccountTier.ValueType = ...,
        jfrog_tenant_details: qwak.administration.account.v1.jfrog_tenant_details_pb2.JfrogTenantDetails | None = ...,
        accepted_terms: qwak.administration.account.v1.terms_pb2.AccountAcceptedTerms | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "jfrog_tenant_details", b"jfrog_tenant_details", "preferences", b"preferences"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_terms", b"accepted_terms", "account_id", b"account_id", "account_name", b"account_name", "default_environment_id", b"default_environment_id", "environments_by_id", b"environments_by_id", "jfrog_tenant_details", b"jfrog_tenant_details", "preferences", b"preferences", "tier", b"tier", "type", b"type"]) -> None: ...

global___AccountReady = AccountReady

class AccountDoesntExist(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_ENTITLED_TO_JFROG_ML_FIELD_NUMBER: builtins.int
    HAS_CREATE_ACCOUNT_PERMISSION_FIELD_NUMBER: builtins.int
    is_entitled_to_jfrog_ml: builtins.bool
    """Defines if the tenant is entitled to JFrog ML"""
    has_create_account_permission: builtins.bool
    """Defines if the user has create account permission"""
    def __init__(
        self,
        *,
        is_entitled_to_jfrog_ml: builtins.bool = ...,
        has_create_account_permission: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_create_account_permission", b"has_create_account_permission", "is_entitled_to_jfrog_ml", b"is_entitled_to_jfrog_ml"]) -> None: ...

global___AccountDoesntExist = AccountDoesntExist

class EnvironmentDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    CONFIGURATION_FIELD_NUMBER: builtins.int
    CLUSTER_ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Environment id"""
    name: builtins.str
    """Environment name"""
    @property
    def configuration(self) -> qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration:
        """Environment configuration"""
    cluster_id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        configuration: qwak.administration.v0.environments.configuration_pb2.QwakEnvironmentConfiguration | None = ...,
        cluster_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["configuration", b"configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_id", b"cluster_id", "configuration", b"configuration", "id", b"id", "name", b"name"]) -> None: ...

global___EnvironmentDetails = EnvironmentDetails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qwak/administration/v1/environments/environment.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from _qwak_proto.qwak.administration.runtime_configuration.v0 import runtime_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_runtime__config__pb2
from _qwak_proto.qwak.administration.runtime_configuration.v0 import network_config_pb2 as qwak_dot_administration_dot_runtime__configuration_dot_v0_dot_network__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5qwak/administration/v1/environments/environment.proto\x12\"qwak.administration.v1.environment\x1a\x41qwak/administration/runtime_configuration/v0/runtime_config.proto\x1a\x41qwak/administration/runtime_configuration/v0/network_config.proto\"\x9b\x02\n\x1c\x45nvironmentRuntimeConfigSpec\x12\x63\n\x15runtime_configuration\x18\x01 \x01(\x0b\x32\x42.qwak.administration.runtime_configuration.v0.RuntimeConfigurationH\x00\x12{\n\x15network_configuration\x18\x02 \x01(\x0b\x32\\.qwak.administration.runtime_configuration.v0.network_config.EnvironmentNetworkConfigurationB\x19\n\x17optional_runtime_configB\xb5\x01\n!com.qwak.ai.administration.v1.apiP\x01Z\x8d\x01github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v1/environments;environment_v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'qwak.administration.v1.environments.environment_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!com.qwak.ai.administration.v1.apiP\001Z\215\001github.com/qwak-ai/qwak-platform/services/core/java/user-management/user-management-api/pb/qwak/administration/v1/environments;environment_v1'
  _globals['_ENVIRONMENTRUNTIMECONFIGSPEC']._serialized_start=228
  _globals['_ENVIRONMENTRUNTIMECONFIGSPEC']._serialized_end=511
# @@protoc_insertion_point(module_scope)
